@@ -10,7 +10,7 @@ use Type::Registry;
 
 require Carp;
 
-our $VERSION = '0.11'; # VERSION
+our $VERSION = '0.12'; # VERSION
 
 # ATTRIBUTES
 
@@ -74,6 +74,10 @@ sub construct_name {
   my $parser = $self->parser;
   my $name = $parser->name;
 
+  if (my $tagline = $parser->tagline) {
+    $name->[0] = $name->[0] .' - '. $tagline->[0] if @$tagline;
+  }
+
   return $self->head1('name', $name);
 }
 
